==> cbol-1.5.tgz: cbol-1.5/font.php <==
<?php
function pfont($message) //ΨshowXrϧ
{
  $BASEDIR="pfont/"; //rͥؿ
  $fontsize=24;    //rjp
  //$fontfile="Bsthebre.ttf";  //rɮ
  $fontfile="/usr/local/share/fonts/cobsh.ttf";  //rɮ
  if(strlen(trim($message))==0) 
  return $message;                                              
  $restxt="";
  $TEXTL = split ("[\r\n]", $message);
  for ($j=0;$j<count($TEXTL);$j++)
  {
      if(strlen(trim($TEXTL[$j]))==0) continue;
     $TEXTA = split (" ", $TEXTL[$j]);
     for ($i=0;$i<count($TEXTA);$i++) 
     {
	if(strlen(trim($TEXTA[$i]))==0) continue;
	if(strcmp($TEXTA[$i],"-")==0) $TEXTA[$i]=" -";// - r
      $sfile=bin2hex($TEXTA[$i]);
      $spdir=substr($sfile,0,2);
      $filename=$BASEDIR.$spdir."/".$sfile.".png";
     /***** Process PNG GRAPH *****/
     if (!is_dir("{$BASEDIR}{$spdir}")) mkdir("{$BASEDIR}{$spdir}",0755);
     if (!file_exists($filename))
      {
        $FSIZE=imagettfbbox($fontsize,0,$fontfile,$TEXTA[$i]);
	$GX=$FSIZE[2]-$FSIZE[0]+2;
        $GY=$FSIZE[3]-$FSIZE[5];
	$YOFFSET=$GY/2;
	$GY=$GY+$YOFFSET;
        $pif1=ImageCreate($GX,$GY);
      	$BGCOLOR=ImageColorAllocate($pif1,255,255,255);//I
	$trans=imagecolortransparent($pif1,$BGCOLOR);
      	$text_col=ImageColorAllocate($pif1,0,0,0x90);//rC
      	imagefill($pif1,0,0,$BGCOLOR); //]wIC
      	ImageTTFText($pif1,$fontsize,0,0,$GY-$YOFFSET,$text_col,$fontfile,$TEXTA[$i]);
      	ImagePNG($pif1,$filename);
      	ImageDestroy($pif1);
      }
      $restxt=$restxt."<img align=\"center\" src=\"$filename\">&nbsp;&nbsp;";
   } //for i
    if ($j<(count($TEXTL)-1))
       $restxt=$restxt."<br>";
  } //for j
   return $restxt;
}
?>

==> cbol-3.0.tgz: cbol-3.0/font.php <==
<?php
function pfont($message) //ΨshowXrϧ
{
  $BASEDIR="pfont/"; //rͥؿ
  $fontsize=24;    //rjp
  //$fontfile="Bsthebre.ttf";  //rɮ
  $fontfile="/usr/local/share/fonts/cobsh.ttf";  //rɮ
  if(strlen(trim($message))==0) 
  return $message;                                              
  $restxt="";
  $TEXTL = split ("[\r\n]", $message);
  for ($j=0;$j<count($TEXTL);$j++)
  {
      if(strlen(trim($TEXTL[$j]))==0) continue;
     $TEXTA = split (" ", $TEXTL[$j]);
     for ($i=0;$i<count($TEXTA);$i++) 
     {
	if(strlen(trim($TEXTA[$i]))==0) continue;
	if(strcmp($TEXTA[$i],"-")==0) $TEXTA[$i]=" -";// - r
      $sfile=bin2hex($TEXTA[$i]);
      $spdir=substr($sfile,0,2);
      $filename=$BASEDIR.$spdir."/".$sfile.".png";
     /***** Process PNG GRAPH *****/
     if (!is_dir("{$BASEDIR}{$spdir}")) mkdir("{$BASEDIR}{$spdir}",0755);
     if (!file_exists($filename))
      {
        $FSIZE=imagettfbbox($fontsize,0,$fontfile,$TEXTA[$i]);
	$GX=$FSIZE[2]-$FSIZE[0]+2;
        $GY=$FSIZE[3]-$FSIZE[5];
	$YOFFSET=$GY/2;
	$GY=$GY+$YOFFSET;
        $pif1=ImageCreate($GX,$GY);
      	$BGCOLOR=ImageColorAllocate($pif1,255,255,255);//I
	$trans=imagecolortransparent($pif1,$BGCOLOR);
      	$text_col=ImageColorAllocate($pif1,0,0,0x90);//rC
      	imagefill($pif1,0,0,$BGCOLOR); //]wIC
      	ImageTTFText($pif1,$fontsize,0,0,$GY-$YOFFSET,$text_col,$fontfile,$TEXTA[$i]);
      	ImagePNG($pif1,$filename);
      	ImageDestroy($pif1);
      }
      $restxt=$restxt."<img align=\"middle\" src=\"$filename\" alt=\"orig\"/>&nbsp;&nbsp;";
   } //for i
    if ($j<(count($TEXTL)-1))
       $restxt=$restxt."<br />";
  } //for j
   return $restxt;
}
?>
